//
//  MiniDBAppDelegate.m
//  MiniDB
//
//  Created by Holger Hinzberg
//  http://www.cocoa-coding.de/kids 

#import "MiniDBAppDelegate.h"
#import "Person.h"

@implementation MiniDBAppDelegate
@synthesize name;
@synthesize vorname;
@synthesize alter;
@synthesize window;
@synthesize buttonVorherige;
@synthesize buttonNaechste;
@synthesize menuNeu;
@synthesize buttonSpeichern;
@synthesize buttonAbbrechen;
@synthesize buttonLetzte;
@synthesize buttonErste;

NSMutableArray *personenArray;

- (void)awakeFromNib
{ 
    personenArray = [[NSMutableArray alloc] init];
    
    indexPosition = 0;
    [buttonSpeichern setEnabled:NO];
    [buttonAbbrechen setEnabled:NO];

}

- (IBAction)dateiLaden:(id)sender
{
    // Konfiguration des NSOpenPanel
    NSOpenPanel *meinOpenPanel =
    [NSOpenPanel openPanel];
    [meinOpenPanel setTitle:@"MiniDB laden"];
    [meinOpenPanel setPrompt:@"Laden"];
    
    if([meinOpenPanel runModal] == NSOKButton)
    {
        // Das Array leeren
        [personenArray removeAllObjects];
        
        NSString *dateiname =
        [[meinOpenPanel URL] path];
        
        personenArray =[NSKeyedUnarchiver
          unarchiveObjectWithFile:dateiname];
        
        // Nach dem laden zur ersten
        // Position springen.        
        indexPosition = 0;
        [self zeigePerson:indexPosition];
    }
}

- (IBAction)dateiSpeichern:(id)sender
{
    // Ein Array für die erlaubten Dateiendungen.
    // Es könnten auch mehrere sein, deshlab ein Array.
    NSArray *dateitypen =
    [[NSArray alloc] initWithObjects:@"mdb",nil];
       
    // Das Panel erzeugen und konfigurieren.
    NSSavePanel *meinSavePanel = 
    [NSSavePanel savePanel];
    [meinSavePanel setAllowedFileTypes:dateitypen];
    [meinSavePanel setTitle:@"MiniDB speichern"];
    [meinSavePanel setPrompt:@"Speichern"];
    
    // Panel anzeigen.
    if([meinSavePanel runModal] == NSOKButton)
    {
        NSString *dateiname =
            [[meinSavePanel URL] path];
        
        BOOL result =
        [NSKeyedArchiver archiveRootObject:
         personenArray toFile:dateiname];
        
        if (result == YES)
        {
            NSRunAlertPanel(@"MiniDB speichern",
                            @"Die Daten wurden erfolgreich gespeichert.",
                            @"OK", nil, nil);
        }
        else
        {
            NSRunAlertPanel(@"MiniDB speichern",
                            @"Die Daten konnten nicht gespeichert werden.",
                            @"OK", nil, nil);
        }

    }
}

- (IBAction)klickVorherige:(id)sender
{
    indexPosition--;
    
    if(indexPosition < 0)
    {
        indexPosition = 0;
    }
    
    [self zeigePerson:indexPosition];
}

- (IBAction)klickNaechste:(id)sender
{
    indexPosition++;
    
    int maxPosition = 
       (int)[personenArray count] -1;
    
    if(indexPosition > maxPosition)
    {
        indexPosition = maxPosition;
    }
    
    [self zeigePerson:indexPosition];
}

- (IBAction)klickErste:(id)sender
{
    indexPosition = 0;
    [self zeigePerson:indexPosition];
}

- (IBAction)klickLetzte:(id)sender
{
    indexPosition = (int)[personenArray count] - 1;
    [self zeigePerson:indexPosition];
}

- (IBAction)klickNeu:(id)sender
{
    // Diese Schaltflächen aktivieren
    [buttonSpeichern setEnabled:YES];
    [buttonAbbrechen setEnabled:YES];
    
    // Diese Schaltflächen müssen inaktiv werden
    [buttonErste setEnabled:NO];
    [buttonLetzte setEnabled:NO];
    [buttonVorherige setEnabled:NO];
    [buttonNaechste setEnabled:NO];
    [menuNeu setEnabled:NO];
    
    // Die Textfelder leeren
    [name setStringValue:@""];
    [vorname setStringValue:@""];
    [alter setStringValue:@""];
}

- (IBAction)klickSpeichern:(id)sender 
{
    // Ein Personenobjekt erzeugen
    Person *neuePerson;
    neuePerson = [[Person alloc] init];
    
    // Werte aus der Oberfläche holen
    [neuePerson setName:[name stringValue]];
    [neuePerson setVorname:[vorname stringValue]];
    [neuePerson setAlter:[alter intValue]];
    
    // Dem Array hinzufügen
    [personenArray addObject:neuePerson];
    
    // Diese Schaltflächen werden inaktiv
    [buttonSpeichern setEnabled:NO];
    [buttonAbbrechen setEnabled:NO];
    
    // Diese Schaltflächen werden aktiv
    [buttonErste setEnabled:YES];
    [buttonLetzte setEnabled:YES];
    [buttonVorherige setEnabled:YES];
    [buttonNaechste setEnabled:YES];
    [menuNeu setEnabled:YES];
    
    // Zur letzten im Array springen, denn
    // dort befindet sich das neu hinzugefügte Objekt
    indexPosition =(int)[personenArray count] - 1;
    [self zeigePerson:indexPosition];
    
    NSRunAlertPanel(@"Person eingefügt",
                    @"Eine weitere Person wurde gespeichert.",
                    @"OK", nil, nil);

}

- (IBAction)klickAbbrechen:(id)sender
{
    // Diese Schaltflächen werden inaktiv
    [buttonSpeichern setEnabled:NO];
    [buttonAbbrechen setEnabled:NO];
    
    // Diese Schaltflächen werden aktiv
    [buttonErste setEnabled:YES];
    [buttonLetzte setEnabled:YES];
    [buttonVorherige setEnabled:YES];
    [buttonNaechste setEnabled:YES];
    [menuNeu setEnabled:YES];
    
    // Eine Person anzeigen
    [self zeigePerson:indexPosition];
}

- (void)zeigePerson:(int)index
{
    if(index < [personenArray count])
    {
        Person *einePerson = [personenArray objectAtIndex:index];
    
        [name setStringValue:[einePerson name]];
        [vorname setStringValue:[einePerson vorname]];
        [alter setIntValue:[einePerson alter]];
    
        [self pruefeButton];
    }
}

- (void)pruefeButton
{
    // Überprüfung Button "Vorherige"
    if(indexPosition == 0)
    {
        [buttonVorherige setEnabled:NO];
    }
    else
    {
        [buttonVorherige setEnabled:YES];
    }
    
    // Überprüfung Button "Nächste"
    if(indexPosition == ((int)[personenArray count] - 1) )
    {
        [buttonNaechste setEnabled:NO];
    }
    else
    {
        [buttonNaechste setEnabled:YES];
    }
}

@end
